==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/MediaGraphRtspSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.MediaGraphRtspTransport
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * RTSP source.
 * @property endpoint RTSP endpoint of the stream being connected to.
 * @property name Source name.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.MediaGraphRtspSource'.
 * @property transport Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
 */
public data class MediaGraphRtspSourceArgs(
    public val endpoint: Output<Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>>,
    public val name: Output<String>,
    public val odataType: Output<String>,
    public val transport: Output<Either<String, MediaGraphRtspTransport>>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs =
        com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs.builder()
            .endpoint(
                endpoint.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .transport(
                transport.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [MediaGraphRtspSourceArgs].
 */
@PulumiTagMarker
public class MediaGraphRtspSourceArgsBuilder internal constructor() {
    private var endpoint: Output<Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>>? =
        null

    private var name: Output<String>? = null

    private var odataType: Output<String>? = null

    private var transport: Output<Either<String, MediaGraphRtspTransport>>? = null

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("hpnqdcavrakgqbao")
    public suspend
    fun endpoint(`value`: Output<Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>>) {
        this.endpoint = value
    }

    /**
     * @param value Source name.
     */
    @JvmName("bbejmmurbdhcuvgw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.MediaGraphRtspSource'.
     */
    @JvmName("hofeyruhnxnnishp")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("fcsihvjaaqkhdhkg")
    public suspend fun transport(`value`: Output<Either<String, MediaGraphRtspTransport>>) {
        this.transport = value
    }

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("mdjkuslbmrvvlbcl")
    public suspend
    fun endpoint(`value`: Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("fueybpqiyjcnsuhy")
    public fun endpoint(`value`: MediaGraphClearEndpointArgs) {
        val toBeMapped = Either.ofLeft<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("ihnqxxrcohrwsuth")
    public fun endpoint(`value`: MediaGraphTlsEndpointArgs) {
        val toBeMapped = Either.ofRight<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value Source name.
     */
    @JvmName("uivvqfoluawwgtej")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.MediaGraphRtspSource'.
     */
    @JvmName("cqgbtjebjanmrjbq")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("kiixucyesejgnaro")
    public suspend fun transport(`value`: Either<String, MediaGraphRtspTransport>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transport = mapped
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("mdyyitmgwvcrsbur")
    public fun transport(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MediaGraphRtspTransport>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transport = mapped
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("pullntiepxyiywws")
    public fun transport(`value`: MediaGraphRtspTransport) {
        val toBeMapped = Either.ofRight<String, MediaGraphRtspTransport>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transport = mapped
    }

    internal fun build(): MediaGraphRtspSourceArgs = MediaGraphRtspSourceArgs(
        endpoint = endpoint ?: throw PulumiNullFieldException("endpoint"),
        name = name ?: throw PulumiNullFieldException("name"),
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        transport = transport ?: throw PulumiNullFieldException("transport"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/MediaGraphRtspSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.MediaGraphRtspTransport
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * RTSP source.
 * @property endpoint RTSP endpoint of the stream being connected to.
 * @property name Source name.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.MediaGraphRtspSource'.
 * @property transport Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
 */
public data class MediaGraphRtspSourceArgs(
    public val endpoint: Output<Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>>,
    public val name: Output<String>,
    public val odataType: Output<String>,
    public val transport: Output<Either<String, MediaGraphRtspTransport>>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs =
        com.pulumi.azurenative.media.inputs.MediaGraphRtspSourceArgs.builder()
            .endpoint(
                endpoint.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .transport(
                transport.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [MediaGraphRtspSourceArgs].
 */
@PulumiTagMarker
public class MediaGraphRtspSourceArgsBuilder internal constructor() {
    private var endpoint: Output<Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>>? =
        null

    private var name: Output<String>? = null

    private var odataType: Output<String>? = null

    private var transport: Output<Either<String, MediaGraphRtspTransport>>? = null

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("acdveqwnnpspoqje")
    public suspend
    fun endpoint(`value`: Output<Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>>) {
        this.endpoint = value
    }

    /**
     * @param value Source name.
     */
    @JvmName("trqjjgeeybnamkjl")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.MediaGraphRtspSource'.
     */
    @JvmName("tbadvknqjmawcofq")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("trjqlknibpjahbwd")
    public suspend fun transport(`value`: Output<Either<String, MediaGraphRtspTransport>>) {
        this.transport = value
    }

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("laggjrpowiiwadbx")
    public suspend
    fun endpoint(`value`: Either<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("qxcbgcwldbbvscep")
    public fun endpoint(`value`: MediaGraphClearEndpointArgs) {
        val toBeMapped = Either.ofLeft<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value RTSP endpoint of the stream being connected to.
     */
    @JvmName("gfhstrnwmwboqrbr")
    public fun endpoint(`value`: MediaGraphTlsEndpointArgs) {
        val toBeMapped = Either.ofRight<MediaGraphClearEndpointArgs, MediaGraphTlsEndpointArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value Source name.
     */
    @JvmName("eolotcpdghaqbdky")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.MediaGraphRtspSource'.
     */
    @JvmName("rqguoleebcbmpgch")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("onxbdtagceksorfj")
    public suspend fun transport(`value`: Either<String, MediaGraphRtspTransport>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transport = mapped
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("tbuhxqsxfxykpyhf")
    public fun transport(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MediaGraphRtspTransport>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transport = mapped
    }

    /**
     * @param value Underlying RTSP transport. This can be used to enable or disable HTTP tunneling.
     */
    @JvmName("jokvyjngqwitcavd")
    public fun transport(`value`: MediaGraphRtspTransport) {
        val toBeMapped = Either.ofRight<String, MediaGraphRtspTransport>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transport = mapped
    }

    internal fun build(): MediaGraphRtspSourceArgs = MediaGraphRtspSourceArgs(
        endpoint = endpoint ?: throw PulumiNullFieldException("endpoint"),
        name = name ?: throw PulumiNullFieldException("name"),
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        transport = transport ?: throw PulumiNullFieldException("transport"),
    )
}
